.. C_DOC documentation master file, created by
   sphinx-quickstart on Mon Aug 10 05:27:13 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PyCodata documentation!
=========================================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   getting_started/index.rst
   releases/index.rst
   api/index.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
